@@ -4,7 +4,7 @@
 // Author:      Vadim Zeitlin
 // Modified by:
 // Created:     20.11.99
-// RCS-ID:      $Id: gdiimage.cpp,v 1.24.2.2 2002/09/21 23:01:25 VZ Exp $
+// RCS-ID:      $Id: gdiimage.cpp,v 1.24.2.3 2004/02/02 14:16:25 CE Exp $
 // Copyright:   (c) 1999 Vadim Zeitlin <zeitlin@dptmaths.ens-cachan.fr>
 // Licence:     wxWindows license
 ///////////////////////////////////////////////////////////////////////////////
@@ -534,7 +534,7 @@ bool wxICOResourceHandler::LoadIcon(wxIcon *icon,
 
     // note that we can't just always call LoadImage() because it seems to do
     // some icon rescaling internally which results in very ugly 16x16 icons
-#if defined(__WIN32__) && !defined(__SC__)
+#if defined(__WIN32__) && (!defined(__SC__) || defined (__DIGITALMARS__) )
     if ( hasSize )
     {
         hicon = (HICON)::LoadImage(wxGetInstance(), name, IMAGE_ICON,
